@@ -1,4 +1,6 @@
 #!/bin/sh
+set -e
+
 DOMAIN=tilix
 BASEDIR=$(dirname $0)
 OUTPUT_FILE=${BASEDIR}/po/${DOMAIN}.pot
@@ -41,6 +43,10 @@ xgettext \
   --language=Desktop \
   ${BASEDIR}/data/pkg/desktop/com.gexperts.Tilix.desktop.in
 
+TMP_METAINFO_FILE=${BASEDIR}/data/metainfo/com.gexperts.Tilix.appdata.xml.rel.in
+appstreamcli news-to-metainfo ${BASEDIR}/NEWS \
+  ${BASEDIR}/data/metainfo/com.gexperts.Tilix.appdata.xml.in \
+  ${TMP_METAINFO_FILE}
 xgettext \
   --join-existing \
   --output $OUTPUT_FILE \
@@ -49,24 +55,33 @@ xgettext \
   --directory=$BASEDIR \
   --foreign-user \
   --language=appdata \
-  ${BASEDIR}/data/appdata/com.gexperts.Tilix.appdata.xml.in
+  ${TMP_METAINFO_FILE}
+rm -f ${TMP_METAINFO_FILE}
 
 # Merge the messages with existing po files
 echo "Merging with existing translations... "
 for file in ${BASEDIR}/po/*.po
 do
   echo -n $file
-  msgmerge --update $file $OUTPUT_FILE
+  msgmerge -F --update $file $OUTPUT_FILE
 done
 
+echo "Updating LINGUAS file..."
+find ${BASEDIR}/po \
+        -type f \
+        -iname "*.po" \
+        -printf '%f\n' \
+        | grep -oP '.*(?=[.])' | sort \
+        > ${BASEDIR}/po/LINGUAS
+
 # Update manpage translations
 echo "Updating manpage translations..."
 if type po4a-updatepo >/dev/null 2>&1; then
   MANDIR=${BASEDIR}/data/man
-  po4a-gettextize -f man -m ${MANDIR}/tilix -p ${MANDIR}/po/tilix.man.pot
+  po4a-gettextize -f man -m ${MANDIR}/tilix.1 -p ${MANDIR}/po/tilix.1.man.pot
   for file in ${MANDIR}/po/*.man.po
   do
     echo -n $file
-    po4a-updatepo -f man -m ${MANDIR}/tilix -p $file
+    po4a-updatepo -f man -m ${MANDIR}/tilix.1 -p $file
   done
 fi
